--- src/examples/recording/recording.cpp.orig	2005-07-25 11:22:31 UTC
+++ src/examples/recording/recording.cpp
@@ -27,6 +27,7 @@
      **************************************************************/
 
 #include <iostream>
+#include <cstdlib>
 
 // Used in step 1
 #include "tse3/Metronome.h"
