--- include/Surelog/DesignCompile/CompileHelper.h.orig	2022-09-09 21:48:59 UTC
+++ include/Surelog/DesignCompile/CompileHelper.h
@@ -29,6 +29,7 @@
 #include <Surelog/Expression/ExprBuilder.h>
 #include <Surelog/SourceCompile/VObjectTypes.h>
 
+#include <filesystem>
 #include <string>
 #include <unordered_map>
 
