--- mapm/mapm.h.orig	1993-02-09 16:35:06 UTC
+++ mapm/mapm.h
@@ -19,7 +19,7 @@
 #define command void /* needed if INC_SHELL was not defined */
 #endif
 
-#include "system.h"
+#include "../lib/system.h"
 
 
 /***************** MAPM Constants *****************/
