--- src/items/itembase.cpp.orig	2025-10-07 13:46:45 UTC
+++ src/items/itembase.cpp
@@ -55,6 +55,8 @@ along with Fritzing.  If not, see <http://www.gnu.org/
 #include <QClipboard>
 #include <qmath.h>
 
+#include <cstdint>
+
 /////////////////////////////////
 
 static QRegularExpression NumberMatcher;
@@ -2006,8 +2008,8 @@ void ItemBase::debugInfo2(const QString & msg) const
 	                   .arg(this->instanceTitle())
 	                   .arg(this->viewLayerID())
 	                   .arg(this->viewLayerPlacement())
-	                   .arg(this->wireFlags())
-			   .arg((long) dynamic_cast<const QGraphicsItem *>(this), 0, 16)
+	                   .arg(this->wireFlags().toInt())
+	                   .arg(static_cast<long>(reinterpret_cast<std::uintptr_t>(dynamic_cast<const QGraphicsItem *>(this))), 0, 16)
 	                   .arg(m_viewID)
 	                   .arg(this->zValue())
 	                   .arg(this->pos().x())
