--- update-bash-completion.sh.orig	2023-07-08 20:59:08 UTC
+++ update-bash-completion.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/bin/sh
 
 # sed - without printing by default (-n)
 # Remove lines up to and including the start line, which includes: START_TARGET_LIST_LINE
