--- videocapt/imagesettings.h.orig	2019-04-18 21:14:43 UTC
+++ videocapt/imagesettings.h
@@ -41,7 +41,6 @@
 #ifndef IMAGESETTINGS_H
 #define IMAGESETTINGS_H
 
-#include <linux/types.h>          /* for videodev2.h */
 #include <linux/videodev2.h>
 
 #include <QDialog>
