--- setup.py.orig	2021-10-13 15:57:11 UTC
+++ setup.py
@@ -32,7 +32,7 @@ setup(name='deeptoolsintervals',
       author_email="ryan@ie-freiburg.mpg.de",
       url="https://github.com/deeptools/deeptools_intervals",
       keywords=["bioinformatics", "GTF"],
-      classifier=["Development Status :: 5 - Production/Stable",
+      classifiers=["Development Status :: 5 - Production/Stable",
                   "Environment :: Console",
                   "License :: OSI Approved :: MIT License",
                   "Intended Audience :: Developers",
