--- apps/alsa_loopback.cc.orig	2021-07-11 19:50:52 UTC
+++ apps/alsa_loopback.cc
@@ -21,7 +21,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
-#include <zita-alsa-pcmi.h>
+#include "zita-alsa-pcmi.h"
 #include "pxthread.h"
 
 
