--- ac2yd/remote.c.orig	2023-12-12 20:34:47 UTC
+++ ac2yd/remote.c
@@ -28,6 +28,7 @@
 #include <sys/socket.h>
 #include <arpa/inet.h>
 #include <netinet/ip.h>
+#include <netinet/in.h>
 #include <fcntl.h>
 #endif
 
